Learn R Programming

ILSAmerge (version 1.2.5)

ILSAdownload: Download ILSA data

Description

Downloads 'SPSS' data from different International Large-Scale Assessments (ILSA). This functions supports the following ILSA: 'PISA', 'TIMSS', 'TIMSS Advanced', 'PIRLS', 'ICCS', 'ICILS', 'CIVED', 'REDS', 'RLII', and 'SITES.' Depending on the study, you will need to decide which data to download, and read and accept its terms and conditions to proceed with the download.

Usage

ILSAdownload(
  study,
  year,
  outputdir = getwd(),
  unzip = FALSE,
  maxtime = 999,
  quiet = FALSE,
  agreeLicense = FALSE
)

Value

Saves 'SPSS' ILSA data locally.

Arguments

study

a string indicating the name of the study. For available studies check the description of this function.

year

a numeric value indicating the year of the study.

outputdir

the directory where the merged data will be saved.

unzip

a logical value indicating if files should be unzipped. Default is FALSE.

maxtime

a numeric value indicating the maximum time allowed for downloading a file. Default is 999.

quiet

a logical value indicating if status of progress should be shown. If a study has sub-studies, e.g. 'PISA' 2009 and this is TRUE, only the main study will be downloaded. Default is FALSE.

agreeLicense

a logical value indicating if you agree with the Disclaimer and License Agreement file from www.iea.nl. If FALSE, you will be prompted to agree with it or else data will not be downloaded. Default is FALSE.

Examples

Run this code
# For example, to download 'RLII' 1991 data:

# Path were files will be saved
dir.create(file.path(tempdir(),"ILSAdownload"))
output <- file.path(tempdir(),"ILSAdownload")


# Downloading 'RLII' 1991 and unzipping files
ILSAdownload(study = "RLII", year = 1991, outputdir = output, unzip = TRUE, agreeLicense = TRUE)


Run the code above in your browser using DataLab